<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-es',
'0_langue' => 'Euskara [eu]',
'0_liste' => 'info@interneteuskadi.org',
'0_mainteneur' => 'info@interneteuskadi.org',

// A
'access_interface_graphique' => 'Interfaz grafiko osora itzuli',
'access_mode_texte' => 'Testu moduan laburtutako interfaz-a erakutsi.',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Artikulu hau aldatu',
'admin_modifier_auteur' => 'Egile hau aldatu',
'admin_modifier_breve' => 'Aldatu berri labur hau',
'admin_modifier_mot' => 'Gako-hitz hau aldatu',
'admin_modifier_rubrique' => 'Atal hau aldatu',
'admin_recalculer' => 'Orrialde hau gaurkotu',
'afficher_trad' => 'Itzulpenak afitxatu',
'alerte_maj_impossible' => 'Erne! SQL basea ezin da gaurkotu @bertsio@ bertsioan, datu-basea aldatzeko eskubide arazo bat dago, agian. Arren, jarri harremanetan zure ostatu-administratzailearekin.',
'alerte_modif_info_concourante' => 'KONTUZ : Informazio hau aldatua izan da bestalde. Gaurko balorea hau da&nbsp;:',
'analyse_xml' => 'XML analisia',
'annuler' => 'Ezeztatu',
'antispam_champ_vide' => 'Otoi, ez ezer ezarri eremu hunetan&nbsp;:',
'articles_recents' => 'Azken artikuluak',
'avis_archive_incorrect' => 'Artxibo-fitxategia ez da Spip motakoa.',
'avis_archive_invalide' => 'artxibo-fitxategia ez da zuzena',
'avis_attention' => 'Adi egon!',
'avis_champ_incorrect_type_objet' => '(@name@) eremu-izena ez da zuzena(@type@) objektu motarentzat',
'avis_colonne_inexistante' => 'Ez dago @col@ zutaberik',
'avis_echec_syndication_01' => 'Sindikazioak huts egin du: adierazitako "backend" delakoa ulertezina da edo ez du artikulurik proposatzen.',
'avis_echec_syndication_02' => 'Sindikazioak huts egin du: leku honen "backend" delakora iristea ezinezkoa da.',
'avis_erreur' => 'Errore: ikus beherago.',
'avis_erreur_connexion' => 'Konexio-errorea',
'avis_erreur_cookie' => 'cookie delakoaren arazoa',
'avis_erreur_fonction_contexte' => 'Programazio-errorea. Testu inguru honetan ez da funtzio hau deitu behar.',
'avis_erreur_mysql' => 'SQL errorea',
'avis_erreur_sauvegarde' => 'Errorea (@type@@id_objet@) ! babes-kopia egiterakoan. ',
'avis_erreur_visiteur' => 'Eremu pribatura sartzeko arazoa',

// B
'barre_a_accent_grave' => 'Azentu kamutsadun A maiuskula tartekatu',
'barre_aide' => 'Laburbide tipografikoak erabili itzazu testu formatuaren prozesua hobetzeko',
'barre_e_accent_aigu' => 'E batazentu-markadun E maiuskula',
'barre_eo' => 'E bat Oan sartu',
'barre_eo_maj' => 'E bat O maiuskulan sartu',
'barre_euro' => '&euro; ikurra sartu',
'barre_gras' => '{{Letra lodiz}} jarri',
'barre_guillemets' => '&laquo;Komatxo&raquo; artean jarri',
'barre_guillemets_simples' => '&#147;Bigarren mailako komatxoen&#148; artean jarri',
'barre_intertitre' => '{{{Barne-izenburuan}}} eraldatu',
'barre_italic' => '{Letra Kurtsibaz} jarri',
'barre_lien' => '[Hipertestu lotura->http://...]-an eraldatu',
'barre_lien_input' => 'Zure lotura-helbidea adierazi. http://www.lekuhori.org/karpeta/ motako Web helbide bat adierazi dezakezu, edo gune honen artikulu baten zenbakia adieraztea ere balio du.',
'barre_note' => '[[Orrialde-oinaren oharra]] -an eraldatu',
'barre_paragraphe' => 'Pargrafo bat sortu',
'barre_quote' => '<quote>Mezu bat aipatu</quote>',
'bouton_ajouter_document' => 'Dokumentu bat erantsi',
'bouton_ajouter_image' => 'Irudi bat erantsi',
'bouton_ajouter_image_document' => 'Irudi bat edo dokumentu bat erantsi',
'bouton_changer' => 'Aldatu',
'bouton_chercher' => 'Bilatu',
'bouton_choisir' => 'Aukeratu',
'bouton_download' => 'Telekargatu',
'bouton_enregistrer' => 'Grabatu',
'bouton_radio_desactiver_messagerie_interne' => 'Barne mezularitza desaktibatu',
'bouton_radio_envoi_annonces' => 'Iragarki editorialak igorri ',
'bouton_radio_non_envoi_annonces' => 'Iragarkirik ez igorri',
'bouton_radio_non_envoi_liste_nouveautes' => 'Berrikuntzen zerrenda ez igorri',
'bouton_recharger_page' => 'Orrialde hau berriz kargatu',
'bouton_telecharger' => 'Telekargatu',
'bouton_valider' => 'Onartu',

// C
'cal_apresmidi' => 'arratsaldea',
'cal_jour_entier' => 'egun osoa',
'cal_matin' => 'goiza',
'cal_par_jour' => 'egutegia egunka',
'cal_par_mois' => 'egutegia hilabeteka',
'cal_par_semaine' => 'egutegia asteka',
'choix_couleur_interface' => 'Kolorea',
'choix_interface' => 'Interfazearen hautua',
'colonne' => 'Zutabe',
'confirm_changer_statut' => 'Kontuz, osagai honen egoera aldatzea eskatu duzu, jarraitu nahi al duzu?',
'correcte' => 'zuzena',

// D
'date_aujourdhui' => 'gaur',
'date_avant_jc' => 'aC',
'date_dans' => '@delai@-n',
'date_de_mois_1' => '@nommois@ren @j@a',
'date_de_mois_10' => '@nommois@ren @j@a',
'date_de_mois_11' => '@nommois@ren @j@a',
'date_de_mois_12' => '@nommois@ren @j@a',
'date_de_mois_2' => '@nommois@ren @j@a',
'date_de_mois_3' => '@nommois@ren @j@a',
'date_de_mois_4' => '@nommois@ren @j@a',
'date_de_mois_5' => '@nommois@ren @j@a',
'date_de_mois_6' => '@nommois@ren @j@a',
'date_de_mois_7' => '@nommois@ren @j@a',
'date_de_mois_8' => '@nommois@ren @j@a',
'date_de_mois_9' => '@nommois@ren @j@a',
'date_demain' => 'bihar',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@@heure@-etan',
'date_fmt_jour_mois' => '@nommois@ren @jour@a',
'date_fmt_jour_mois_annee' => '@annee@-ko @nommois@ren @jour@a',
'date_fmt_mois_annee' => '@annee@-ko @nommois@',
'date_fmt_nomjour_date' => '@nomjour@ @date@-a',
'date_heures' => 'orduak',
'date_hier' => 'atzo',
'date_il_y_a' => 'orain dela @delai@',
'date_jnum1' => '1.',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Igandea',
'date_jour_1_abbr' => 'Ig',
'date_jour_1_initiale' => 'Ig',
'date_jour_2' => 'Astelehena',
'date_jour_2_abbr' => 'Al',
'date_jour_2_initiale' => 'Al',
'date_jour_3' => 'Asteartea',
'date_jour_3_abbr' => 'At',
'date_jour_3_initiale' => 'Az',
'date_jour_4' => 'Asteazkena',
'date_jour_4_abbr' => 'Az',
'date_jour_4_initiale' => 'Az',
'date_jour_5' => 'Osteguna',
'date_jour_5_abbr' => 'Os',
'date_jour_5_initiale' => 'Og',
'date_jour_6' => 'Ostirala',
'date_jour_6_abbr' => 'Ol',
'date_jour_6_initiale' => 'Ol',
'date_jour_7' => 'Larunbata',
'date_jour_7_abbr' => 'La',
'date_jour_7_initiale' => 'L',
'date_jours' => 'egunak',
'date_minutes' => 'minutuak',
'date_mois' => 'hilabeteak',
'date_mois_1' => 'urtarrila',
'date_mois_10' => 'urria',
'date_mois_11' => 'azaroa',
'date_mois_12' => 'abendua',
'date_mois_2' => 'otsaila',
'date_mois_3' => 'martxoa',
'date_mois_4' => 'apirila',
'date_mois_5' => 'maiatza',
'date_mois_6' => 'ekaina',
'date_mois_7' => 'uztaila',
'date_mois_8' => 'abuztua',
'date_mois_9' => 'iraila',
'date_saison_1' => 'negua',
'date_saison_2' => 'udaberria',
'date_saison_3' => 'uda',
'date_saison_4' => 'udazkena',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'asteak',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => 'Atariko instalazioa hasi ',
'dirs_preliminaire' => 'Aurretik: <b>sarbide eskubideak arautu </b>',
'dirs_probleme_droits' => 'Sarbide eskubidearekiko arazoak',
'dirs_repertoires_absents' => 'Ezin izan dira hurrengo karpeta hauek aurkitu:@bad_dirs@.
Litekeena da letra larri eta xeheen arteko akats bat izatea. 
Egiazta ezazu karpeta hauen izenen letra larri eta xeheak aurrekoarekin bat datozela; 
hala ez bada, karpeten izena alda ezazu, zure FTP softwarea erabiliz.
Eragiketa hori egin eta gero, gauza izango zara',
'dirs_repertoires_suivants' => '<b>Hurrengo direktorioak ez dituzte idazteko eskubiderik&nbsp;:<ul>@bad_dirs@.</ul></b>
  <p>Arazoa konpontzeko FTP bezero bat erabili beharko duzu lehen aipatu diren direktorioen sarbide
 eskubideak arautzeko helburuz.
 </p><p>Prozedura xehetasunez azaltzen da instalazio gidan. Behin prozedura bukatu ezkero, ahal duzu </p>',
'double_occurrence' => 'Okurenzi bikoitza',

// E
'en_cours' => 'Unekoan',
'entree_dimensions' => 'Dimentsioak',
'entree_titre_document' => 'Agiriaren izenburua :',
'entree_titre_image' => 'Irudiaren izenburua :',
'envoi_via_le_site' => 'Gunearen bitartez egindako bidalpena',
'erreur' => 'Errorea',
'erreur_balise_non_fermee' => 'ez itxitako azken etiketa :',
'erreur_texte' => 'errore',
'etape' => 'Etapa',

// F
'fichier_introuvable' => '@fichier@ aurkitzeko moduan ez dagoen artxiboa',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Inskribaturik zaude jadanik.',
'form_email_non_valide' => 'Posta elektronikoaren helbideak ez du balio.',
'form_forum_access_refuse' => 'Ezin zara gune honetan sartu dagoeneko.',
'form_forum_bonjour' => 'Kaixo @nom@,',
'form_forum_email_deja_enregistre' => 'Dagoeneko, posta elektronikoaren helbide hau erregistraturik dago, beraz ohizko pasahitza erabili dezakezu.',
'form_forum_identifiant_mail' => 'Zure identifikadore berria posta elektonikoaren bidez igorri dugu.',
'form_forum_identifiants' => 'Identifikadore pertsonalak',
'form_forum_indiquer_nom_email' => 'Hemen idatz itzazu zure izena eta posta elektronikoaren helbidea. Zure identifikadore pertsonala berehala igorriko dizugu posta elektronikoaren bidez.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(Hau mezu automatikoa da)',
'form_forum_pass' => 'Pasahitza :',
'form_forum_probleme_mail' => 'Posta elektronikoarekiko arazoa: identifikadorea ezinda igorri.',
'form_forum_voici1' => 'Hona hemen zure identifikadoreak,"@nom_site_spip@" (@adresse_site@) gunearen foroetan parte hartzeko:',
'form_forum_voici2' => 'Hona hemen zure identifikadoreak, artikuluak ,"@nom_site_spip@" (@adresse_login@) gunean proposatzeko:',
'form_indiquer_email' => 'Zure posta elektronikoaren heldibea adierazi.',
'form_indiquer_nom' => 'Zure izena adierazi.',
'form_indiquer_nom_site' => 'Zure webgunearen izena adierazi.',
'form_pet_adresse_site' => 'Zure gunearen helbidea',
'form_pet_aucune_signature' => 'Ez dago kode honi dagokion sinadurarik...',
'form_pet_confirmation' => 'Zure sinadura baieztatu:',
'form_pet_deja_enregistre' => 'Gune hau erregistraturik dago jadanik',
'form_pet_deja_signe' => 'Testu hau dagoeneko sinatu duzu.',
'form_pet_envoi_mail_confirmation' => 'Oraintxe bertan baieztapen-mezu elektroniko bat @email@ helbidera igorri dugu. Mezu horretan aipatutako Web helbidea bisitatu behar duzu zure sinadura onartzeko.',
'form_pet_mail_confirmation' => 'Kaixo, 

@titre@ eskaera sinatzea eskatu duzu.

Hurrengo informazioak eman dituzu: 
   Izena: @nom_email@
   Lekua: @nom_site@ - @url_site@

GARRANTZITSUA... 
Zure sinadura onartzeko, hurrengo helbidera konektatzea beharrezkoa da (bestela, zure eskaera ez da onartuko):

@url@

Milesker parte hartzeagatik ',
'form_pet_message_commentaire' => 'Mezurik, azalpenik ?',
'form_pet_nom_site2' => 'Zure Webgunearen izena',
'form_pet_probleme_liens' => 'Otoi, zure mezua bermoldatu hiperestekak kenduz.',
'form_pet_probleme_technique' => 'Arazo teknikoa, sinadurak behin-behineko etenaldian daude.',
'form_pet_signature_pasprise' => 'Zure sinadura ez da kontuan hartua izan.',
'form_pet_signature_validee' => 'Zure sinadura onartuta dago. Gunearen hurrengo gaurkotzean agertuko da. Eskerrik asko!',
'form_pet_site_deja_enregistre' => 'Gune hau erregistraturik dago jadanik',
'form_pet_url_invalide' => 'Zuk aipatutako URL-ak ez du balio',
'form_pet_votre_email' => 'Zure posta-elektronikoaren helbidea',
'form_pet_votre_nom' => 'Zure izena edo goitizena',
'form_pet_votre_site' => 'Webgune bat baldin baduzu, jarraian adierazi dezakezu',
'form_prop_confirmer_envoi' => 'Bidalketa baieztatu',
'form_prop_description' => 'Deskripzio/oharra',
'form_prop_enregistre' => 'Zure proposamena erregistraturik dago, gune honen arduradunek onartu ondoren agerian linean izango da.',
'form_prop_envoyer' => 'Mezu bat igorri',
'form_prop_indiquer_email' => 'Posta elektronikoaren helbide onargarri bat adieraz ezazu',
'form_prop_indiquer_nom_site' => 'Gunearen izena aipatu',
'form_prop_indiquer_sujet' => 'Gai bat aipatu',
'form_prop_message_envoye' => 'Mezua igorria',
'form_prop_nom_site' => 'Gunearen izena',
'form_prop_non_enregistre' => 'Zure proposamena ez zen erregistratu.',
'form_prop_sujet' => 'Gai',
'form_prop_url_site' => 'Gunearen (URL) helbidea',
'forum_acces_refuse' => 'Dagoeneko ezin zara foro hauetan sartu.',
'forum_attention_dix_caracteres' => '<b>Adi!</b> zure mezuak hamar karaktere baino gutxiago ditu',
'forum_attention_trois_caracteres' => '<b>Adi!</b> zure izenburuak hiru karaktere baino gutxiago ditu.',
'forum_attention_trop_caracteres' => '<b>kontuz&nbsp;!</b> zure mezua luzeegi da (@compte@ caract&egrave;res)&nbsp;: grabatua izateko, ez ditu @max@ karaktero baino gehiago izan behar.',
'forum_avez_selectionne' => 'Aukeratu egin duzu:',
'forum_cliquer_retour' => 'Jarraitzeko hemen klik egin.',
'forum_forum' => 'foroa',
'forum_info_modere' => 'Foro hau aurretiaz moderaturik dago : 
Zure ekarpena gunearen administratzaileak onartu ondoren soilik agerian izango da.',
'forum_lien_hyper' => 'Hipertestu lotura (aukeratzekoa)',
'forum_message_definitif' => 'Behin-betiko mezua : gunera igorri',
'forum_message_trop_long' => 'Zure mezua luzeegia da. Gehienez ere 20000 karaktere onartzen dira.',
'forum_ne_repondez_pas' => 'Ez erantzun mezu elektroniko honi, baizik eta hurrengo helbidean dagoen foroan:',
'forum_non_inscrit' => 'Ez zaude inskribaturik, edota emandako helbidea edo pasahitza ez dira zuzenak.',
'forum_page_url' => '(Zure mezua interneten argitaratutako artikulu bati buruzkoa baldin bada, edo informazio gehiago duen orrialde bati buruzkoa, adieraz itzazu jarraian orrialdearen izena bai eta URL helbidea ere).',
'forum_par_auteur' => '@auteur@-k',
'forum_poste_par' => '&laquo; @titre@ &raquo; artikuluaren ondotik  @parauteur@-k bidalitako mezua.',
'forum_probleme_database' => 'Datu-basearen arazoa, zure mezua ez dago erregistraturik.',
'forum_qui_etes_vous' => '<b>Nor zara zu?</b> (aukeratzekoa)',
'forum_texte' => 'Zure mezuaren testua:',
'forum_titre' => 'Izenburua :',
'forum_titre_erreur' => 'Errore...',
'forum_url' => 'URL :',
'forum_valider' => 'Aukera hori onartu',
'forum_voir_avant' => 'Igorri aurretik mezu hau ikusi',
'forum_votre_email' => 'Zure posta-elektronikoaren helbidea :',
'forum_votre_nom' => 'Zure izena (edo goitizena) :',
'forum_vous_enregistrer' => 'Aurretik inskribatzea beharrezkoa da foro honetan parte hartzeko.
Hornitua izan zaizun identifikadore pertsonala jarraian adieraztea eskertuko dizugu.
Inskribaturik ez bazaude, aurretik inskribatu behar duzu.',
'forum_vous_inscrire' => 'Aurretik inskriba zaitez.',

// I
'ical_texte_rss_articles' => 'Gune honetako artikuluen &laquo;backend&raquo; delako fitxategia hurrengo helbidean dago:',
'ical_texte_rss_articles2' => 'Gune honetako artikuluen &laquo;backend&raquo; delako fitxategia hurrengo helbidean dago:',
'ical_texte_rss_breves' => 'Badago gainera gune honen berri laburrak dituen fitxategi bat. Atalaren zenbakia emanda, honen berri laburrak bakarrik lor daitezke.',
'icone_a_suivre' => 'Nere eginkizunak',
'icone_admin_site' => 'Gunearen administrazioa',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Laguntza',
'icone_articles' => 'Artikuluak',
'icone_auteurs' => 'Egileak',
'icone_breves' => 'Berri laburrak',
'icone_brouteur' => 'Nabigazio bizkorra',
'icone_configuration_site' => 'Gunearen konfigurazioa',
'icone_configurer_site' => 'Zure gunea konfiguratu',
'icone_creer_nouvel_auteur' => 'Egile berri bat eratu',
'icone_creer_rubrique' => 'Atal berri bat eratu',
'icone_creer_sous_rubrique' => 'Azpi-atal berri bat eratu',
'icone_deconnecter' => 'Deskonektatu',
'icone_discussions' => 'Eztabaidak',
'icone_doc_rubrique' => 'Atalen dokumentuak',
'icone_ecrire_article' => 'Artikulu berri bat idatzi',
'icone_edition_site' => 'Gunearen edizioa',
'icone_forum_administrateur' => 'Administratzaileen foroa',
'icone_forum_suivi' => 'Foroen gestioa',
'icone_gestion_langues' => 'Hizkuntzen gestioa',
'icone_informations_personnelles' => 'Informazio pertsonalak',
'icone_interface_complet' => 'Interfaze osoa',
'icone_interface_simple' => 'Interfaze bakuna',
'icone_maintenance_site' => 'Gunearen mantentze-lana',
'icone_messagerie_personnelle' => 'Mezularitza pertsonala',
'icone_mots_cles' => 'Gako-hitzak',
'icone_nouvelle_breve' => 'Labur berri bat eratu',
'icone_repartition_actuelle' => 'Oraingo banaketa erakutsi',
'icone_repartition_debut' => 'Banaketa hasieratik erakutsi ',
'icone_repartition_visites' => 'Bisiten banaketa',
'icone_rubriques' => 'Atalak',
'icone_sauver_site' => 'Gunearen segurtasun kopia egin',
'icone_site_entier' => 'Gune osoa',
'icone_sites_references' => 'Aipatutako guneak',
'icone_statistiques' => 'gunearen estatistikak',
'icone_statistiques_visites' => 'Bisiten estatistikak',
'icone_suivi_activite' => 'Gunearen bizitzaren jarraipena egin',
'icone_suivi_actualite' => 'Gunearen bilakaera',
'icone_suivi_forums' => 'Foroen gestioa',
'icone_suivi_pettions' => 'Eskaeren gestioa',
'icone_suivi_revisions' => 'Artikuluen aldaketak',
'icone_supprimer_document' => 'Dokumentu hau kendu',
'icone_supprimer_image' => 'Irudi hau kendu',
'icone_supprimer_message' => 'Mezu hau kendu',
'icone_tous_articles' => 'Zure artikulu guztiak',
'icone_tous_auteur' => 'Egile guztiak',
'icone_valider_message' => 'Mezu hau onartu',
'icone_visiter_site' => 'Gunea bisitatu',
'icone_voir_en_ligne' => 'Linean ikusi',
'image_tourner_180' => '180 graduko errotazioa',
'image_tourner_droite' => '90 graduko errotazioa eskuinera',
'image_tourner_gauche' => '90 graduko errotazioa ezkerrera',
'img_indisponible' => 'irudi erabilezina',
'impossible' => 'Ezinezkoa',
'info_a_suivre' => 'NIRE LANAK &raquo;',
'info_a_valider' => '[egiaztatzeko]',
'info_acces_interdit' => 'Sarrera debekatua',
'info_acces_refuse' => 'Sarrera ukatuta',
'info_action' => 'Ekintza : @ekintza@',
'info_administrer_rubriques' => 'Atal hau eta bere azpi-atalak kudeatzen ahal dituzu',
'info_adresse_non_indiquee' => 'Ez duzu frogatu nahi duzun helbidea ipini !',
'info_aide' => 'Laguntza :',
'info_ajouter_mot' => 'Hitz hau gehitu',
'info_annonce' => 'Iragarpena',
'info_annonces_generales' => 'Iragarki orokorrak',
'info_article_propose' => 'Artikulua proposatuta',
'info_article_publie' => 'Artikulu argitaratua',
'info_article_redaction' => 'Artikulua idazteko bidean dago',
'info_article_refuse' => 'Artikulu ezeztatuta',
'info_article_supprime' => 'Artikulu ezabatua',
'info_articles' => 'Artikuluak',
'info_articles_a_valider' => 'Egiaztatuak izan behar diren artikuluak',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Proposatutako artikuluak',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'Egileak :',
'info_authentification_ftp' => 'Baimena (FTP-aren bidez).',
'info_bloquer_lien' => 'Lotura hau blokatu',
'info_breves_02' => 'Laburrak',
'info_breves_2' => 'laburrak',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Egiaztatzeko laburrak',
'info_connexion_refusee' => 'Konexioa errefusatu da',
'info_contact_developpeur' => 'Programatzaile batekin kontaktuan jarri behar duzu.',
'info_contenance' => 'Gune honek duena :',
'info_contribution' => 'foroko ekarpenak',
'info_copyright' => '@spip@ software librea da, @lien_gpl@ banatua.',
'info_copyright_doc' => 'Argibide gehiago izateko, jo helbide honetara: <a href="@spipnet@">http://www.spip.net/eu</a>.',
'info_copyright_gpl' => 'GPL lizentziarekin',
'info_cours_edition' => 'Bukatu gabe utzi dituzun artikuluak',
'info_creer_repertoire' => 'Fitxategi edo karpeta bat sortu behar duzu, eta hari izen hau jarri :',
'info_creer_repertoire_2' => '<b>@repertoire@</b>, azpidirektorioan, eta ondotik :',
'info_creer_vignette' => 'miniaturaren sorkuntza automatikoa',
'info_deplier' => 'Desplegatu',
'info_descriptif_nombre' => 'deskribapena(k):',
'info_description' => 'Deskribapena :',
'info_description_2' => 'Deskribapena :',
'info_dimension' => 'Neurriak :',
'info_document' => 'Dokumentua',
'info_document_indisponible' => 'Dokumentu hau ez da erabilgarria',
'info_documents' => 'Dokumentuak',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIPek guneko partehartzaileen arteko mezuen trukaketa eta foro pribatuak ahalbidetzen ditu.
Funtzionalitate hau aktiba edo desaktibatzen ahal duzu.',
'info_ecire_message_prive' => 'Mezu pribatu bat idatzi',
'info_email_invalide' => 'Posta elektronikoko helbidea ez da zuzena.',
'info_en_cours_validation' => 'Idaztear dituzun artikuluak',
'info_en_ligne' => 'Une honetan linean :',
'info_envoyer_message_prive' => 'Mezu pribatua bidali egile honi',
'info_erreur_requete' => 'Errorea eskabidean:',
'info_erreur_squelette2' => 'Ez dago <b>@fichier@</b> eskeletorik erabilgarri...',
'info_erreur_systeme' => 'Akatsa sistema (errno @errsys@)',
'info_erreur_systeme2' => 'Disko gogorra beteta edo datubasea hondatuta egon daiteke.
Basea konpontzen saiatu, edo zure ostalaitzea kontaktatu.',
'info_fini' => 'Bukatuta!',
'info_format_image' => 'Miniaturendako erabil daitezkeen irudi-formatuak @gd_formats@.',
'info_format_non_defini' => 'formatua ez dago definitua',
'info_grand_ecran' => 'Pantaila handia',
'info_image_aide' => 'LAGUNTZA',
'info_image_process_titre' => 'Miniaturen sorkuntzarako metodoa',
'info_impossible_lire_page' => 'Errorea ! Ezinezkoa @test_proxy@ orrialdea irakurtzea"proxy"-aren bidez ',
'info_inclusion_directe' => 'Zuzeneko inklusioa:',
'info_inclusion_vignette' => 'Miniaturaren inklusioa :',
'info_installation_systeme_publication' => 'Argitarapen sistemaren instalazioa...',
'info_installer_documents' => '@upload@ direktorioan dauden dokumentu guztiak automatikoki instalatzen ahal dituzu.',
'info_installer_ftp' => 'Administrazio eskubideekin, @upload@ karpetan fitxategiak instala ditzakezu (FTP bidez), ondotik zuzenean hemen hautatu ahal izateko.',
'info_installer_images' => 'JPEG, GIF eta PNG formatudun irudiak ezar ditzakezu.',
'info_installer_images_dossier' => 'Irudiak instalatu @upload@ karpetan gero zuzenean hemen hautatu ahal izateko.',
'info_installer_tous_documents' => 'Dokumentu guztiak instalatu',
'info_interface_complete' => 'Interfaze osoa',
'info_interface_simple' => 'Interfaze bakuna',
'info_joindre_document_article' => 'Artikulu honi mota honetako dokumentuak erantsi ahal dizkiozu',
'info_joindre_document_rubrique' => 'Sekzio honi mota hunetako dokumentuak eransten ahal dizkiozu',
'info_joindre_documents_article' => 'Zure artikuluari mota huntako dokumentuak eransten ahal dizkiozu :',
'info_l_article' => 'artikulua',
'info_la_breve' => 'Laburra',
'info_la_rubrique' => 'Atala',
'info_langue_principale' => 'Gunearen hizkuntza nagusia',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixelak',
'info_les_auteurs_1' => '@les_auteurs@-engatik',
'info_logo_format_interdit' => '@formats@ formatuko logoak baizik baimenduak dira.',
'info_logo_max_poids' => 'Logoek @maxi@ baino gutxiago pisatu behar dute derrigorrez (artxiboak @actuel@ pisatzen du).',
'info_logo_max_taille' => 'Logoek @maxi@ baino gutxiago neurtu behar dure derrigorrez (artxiboak @actuel@ neurtzen du).',
'info_mail_fournisseur' => 'zure@hornitzailea.com',
'info_message_2' => 'MEZUA',
'info_message_supprime' => 'Mezua ezabatu da',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Argitarapen data :',
'info_modification_parametres_securite' => 'segurtasun-parametroen aldaketa.',
'info_mois_courant' => 'Hilabete honetan:',
'info_mot_cle_ajoute' => 'Hurrengo gako-hitza artikulura gehitua izan da',
'info_multi_herit' => 'Hizkuntza lehenetsia',
'info_multi_langues_soulignees' => '<u>Azpimarratutako</u> hizkuntzek interfazeko testu guztien itzulpen bat eskaintzen dute. 
Hizkuntzak horiek hautatzen badituzu, leku publikoko elementu batzuk (datak, inprimakiak) automatikoki itzuliko dira.
Azpimarratu gabeko hizkuntzetarako, elementuak gunearen hizkuntza nagusian agertuko dira.',
'info_multilinguisme' => 'Hizkuntzaniztasuna',
'info_nom_non_utilisateurs_connectes' => 'Zure izena ez da ageri konektatutako pertsonen zerrendan',
'info_nom_utilisateurs_connectes' => 'Zure izena konektatuta dauden pertsonen zerrendan ageri da.',
'info_nombre_en_ligne' => 'Une honetan linean :',
'info_non_resultat' => '"@cherche_mot@" bilaketak ez du emaitzik eman',
'info_non_utilisation_messagerie' => 'Ez erabili barne-mezularitza.',
'info_nouveau_message' => 'MEZU BERRI BAT BADUZU',
'info_nouveaux_messages' => '@total_messages@ MEZU BERRI BADITUZU',
'info_numero_abbreviation' => 'Zk&nbsp; ',
'info_obligatoire' => 'Informazio hori beharrezkoa da',
'info_panne_site_syndique' => 'Sindikatutako guneak arazoak dauzka',
'info_pense_bete' => 'Buruz ikasteko oroigarria',
'info_petit_ecran' => 'Pantaila txikia',
'info_petition_close' => 'Hetsitako petizioa',
'info_pixels' => 'pixelak',
'info_plusieurs_mots_trouves' => 'Zenbait gako-hitz aurkitu ditugu "@cherche_mot@-arako":',
'info_popularite_5' => 'Arrakasta :',
'info_portfolio' => 'Album-orrialdea',
'info_portfolio_automatique' => 'Album-orrialde automatikoa',
'info_premier_resultat' => '[lehen @debut_limit@ emaitzak; guztira, @total@]',
'info_premier_resultat_sur' => '[lehen @debut_limit@ emaitzak; guztira, @total@]',
'info_probleme_grave' => '-ren arazoa',
'info_propose_1' => '[@nom_site_spip@] Proposatzen du: @titre@',
'info_propose_2' => 'Proposatutako artikulua 
---------------',
'info_propose_3' => '"@titre@" artikulua argitaratua izateko proposatua izan da.',
'info_propose_4' => 'Begiratzera eta zure iritzia ematera gonbidatuta zaude',
'info_propose_5' => 'helbidean dagokizun foroan :',
'info_publie_01' => '"@titre@" artikulua baliozkotu du @connect_nom@(e)k.',
'info_publie_1' => '[@nom_site_spip@] Argitaratzen du: @titre@',
'info_publie_2' => 'Artikulu argitaratua 
--------------',
'info_rechercher' => 'Bilatu',
'info_rechercher_02' => 'Bilatu&nbsp;:',
'info_remplacer_vignette' => 'Ikono lehenetsiaren ordez zuk aukeratutako irudi bat jarri&nbsp;:',
'info_retablir_lien' => 'esteka berrezarri',
'info_retirer_mot' => 'Hitz hau kendu',
'info_retirer_mots' => 'Hitz guztiak kendu',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'izenbururik gabe',
'info_selectionner_fichier' => '<i>Upload</i> direktorioko dokumentu bat hauta dezakezu',
'info_selectionner_fichier_2' => 'Dokumentu bat hautatu&nbsp;:',
'info_signature_supprimee' => 'Sinadura kendua',
'info_signature_supprimee_erreur' => 'Errorea&nbsp;: ezabaketa-kode hau ez da sinadura bati lotua',
'info_site_attente' => 'Balioztatua izateko zain dagoen Webgunea',
'info_site_reference' => 'Linean erreferentziatutako gunea',
'info_site_refuse' => 'Web Gune errefusatua',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Gune bat erreferentziatu',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'miniatura hau kendu',
'info_symbole_bleu' => 'Sinbolo <b>URDIN</b>ak oroigarri pertsonal bat adierazten du, hau da zerbait gogoratzeko modu bat.',
'info_symbole_jaune' => 'Sinbolo <b>hori</b>ak denentzako iragarpen bat adierazten du: gunearen administratzaileek bakarrik alda dezakete, eta idazle guztiek ikus dezakete.',
'info_symbole_vert' => 'Sinbolo <b>berdeak</b> guneko beste pertsonekin trukatutako mezuak adierazten ditu.',
'info_syndication' => 'Sindikazioa&nbsp;:',
'info_syndication_articles' => 'artikulua(k)',
'info_telecharger' => 'Zure ordenagailutik igo :',
'info_telecharger_nouveau_logo' => 'Logo berri bat igo:',
'info_telecharger_ordinateur' => 'Zure ordenagailutik igo :',
'info_tous_resultats_enregistres' => '[emaitza guztiak grabatuak dira]',
'info_tout_afficher' => 'Dena erakutsi',
'info_travaux_texte' => 'Leku hau oraindik konfiguratu gabe dago. Berantago itzuli…',
'info_travaux_titre' => 'Gunea aldatzeko bidean',
'info_trop_resultat' => 'Emaitza gehiegi "@cherche_mot@"-aren bilaketarako. Irizpideak zehaztu.',
'info_utilisation_messagerie_interne' => 'Gunearen barruko mezularitza erabiltzen duzu.',
'info_valider_lien' => 'lotura hau balidatu',
'info_verifier_image' => ', irudiak ondo bidali diren egiaztatu ezazu.',
'info_vignette_defaut' => 'Ikono lehenetsia',
'info_vignette_personnalisee' => 'Egokitutako irudia',
'info_visite' => 'bisita:',
'info_visites' => 'bisitak :',
'info_vos_rendez_vous' => 'Zure hitzorduak',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Zure oroigarriak',
'item_breve_proposee' => 'Proposaturiko berri laburra',

// L
'lien_afficher_icones_seuls' => 'Ikurrak soilik erakutsi',
'lien_afficher_texte_icones' => 'Ikurrak eta testua erakutsi',
'lien_afficher_texte_seul' => 'Testua soilik erakutsi',
'lien_liberer' => 'Askatu',
'lien_liberer_tous' => 'artikulu hauek askatu',
'lien_nouvea_pense_bete' => 'Oroigarri berria',
'lien_nouveau_message' => 'Mezu berria',
'lien_nouvelle_annonce' => 'Iragarpen berria',
'lien_petitions' => 'Eskaera',
'lien_popularite' => 'Arrakasta : @popularite@%',
'lien_racine_site' => 'Gunearen sustraia',
'lien_reessayer' => 'berriro saiatu',
'lien_repondre_message' => 'Mezu honi erantzun',
'lien_supprimer' => 'Kendu',
'lien_tout_afficher' => 'Dena Erakutsi',
'lien_visite_site' => 'Gune hau bisitatu',
'lien_visites' => '@visites@ bisita.',
'lien_voir_auteur' => 'Egile hau ikusi',
'ligne' => 'Lerro',
'login' => 'Konekzioa',
'login_acces_prive' => 'eremu pribaturako sarbidea',
'login_autre_identifiant' => 'beste identifikatzaile batekin konektatu',
'login_cookie_accepte' => 'Zure nabigatzailea konfiguratu onar ditzan (gune honetarako behintzat).',
'login_cookie_oblige' => 'Gune honetan segurtasunez identifikatzeko, "cookieak"onartu behar dituzu.',
'login_deconnexion_ok' => 'Deskonexioa eginda.',
'login_erreur_pass' => 'Pasahitz errorea.',
'login_espace_prive' => 'eremu pribatua',
'login_identifiant_inconnu' => '&laquo;@login@&raquo; identifikatzailea ezezaguna da.',
'login_login' => 'Identifikatzailea :',
'login_login2' => 'Login (gunerako konexio-identifikatzailea):',
'login_login_pass_incorrect' => '(Identifikatzaile edo pasahitz okerra.)',
'login_motpasseoublie' => 'Pasahitza ahaztuta?',
'login_non_securise' => 'Kontuz, inprimaki hau ez da segurtatua.
Zure pasahitza sarean atzeman ahal izatea nahi ez baduzu, JavaScript-a aktibatu zure nabigatzailean eta',
'login_nouvelle_tentative' => 'Ahalegin berria',
'login_par_ici' => 'Erregistratuta zaude... hemendik...',
'login_pass2' => 'Pasahitza :',
'login_preferez_refuser' => '"Cookiak" errefusatzea nahiago baduzu, beste konexio modu bat dago (gutxiz seguruagoa) zure eskura :',
'login_recharger' => 'Orrialde hau berriz kargatu',
'login_rester_identifie' => 'Egun batzuetan identifikatuta geratu',
'login_retour_public' => 'Eremu publikora itzuli',
'login_retour_site' => 'Eremu publikora itzuli',
'login_retoursitepublic' => 'eremu publikora itzuli',
'login_sans_cookiie' => 'Identifikazioa "cookie" barik',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'inskribatu',
'login_test_navigateur' => 'nabigatzaile proba/berkonexioa',
'login_verifiez_navigateur' => '(Hala ere,zure nabigatzaileak zure pasahitza memorizatu ez duela egiaztatu...)',

// M
'masquer_colonne' => 'Zutabe hau maskatu',
'masquer_trad' => 'Itzulpenak ezkutatu',
'module_fichiers_langues' => 'Hizkuntza-fitxategiak',

// N
'navigateur_pas_redirige' => 'Zure nabigatzaileak ez bazaitu automatikoki berriz eramaten, hemen klikatu jarraitzeko.',
'numero' => 'Zenbakia',

// O
'occurence' => 'Okurenzia',
'onglet_affacer_base' => 'Basea ezabatu',
'onglet_auteur' => 'Egilea',
'onglet_contenu_site' => 'Gunearen edukia',
'onglet_evolution_visite_mod' => 'Bilakaera',
'onglet_fonctions_avances' => 'Funtzio aurreratuak',
'onglet_informations_personnelles' => 'Informazio pertsonalak',
'onglet_interactivite' => 'Elkarreragin',
'onglet_messagerie' => 'Mezularitza',
'onglet_messages_internes' => 'Barne mezuak',
'onglet_messages_publics' => 'Mezu publikoak',
'onglet_messages_vide' => 'Testurik gabeko mezuak',
'onglet_origine_visites' => 'Bisiten jatorria',
'onglet_repartition_debut' => 'hasieratik',
'onglet_repartition_lang' => 'Hizkuntzakako banaketa',
'onglet_repartition_rubrique' => 'Atalkako banaketa ',
'onglet_save_restaur_base' => 'Segurtasun kopia sortu eta basea berrezarri',
'onglet_vider_cache' => 'Cachea hustu',
'ortho_trop_de_fautes2' => 'Akats nabarienak zuzentzen hasi eta saiatu berriro.',

// P
'pass_choix_pass' => 'pasahitz berria aukeratu:',
'pass_erreur' => 'Errorea',
'pass_erreur_acces_refuse' => 'Errorea: dagoeneko ez duzu gune honetan sartzeko baimenik.',
'pass_erreur_code_inconnu' => '<b>Errorea :</b> kode hau ez dagokio gune honetan sartu ahal den bisitari bakar bati ere.',
'pass_erreur_non_enregistre' => '<b>Errorea :</b> @email_oubli@ helbidea ez dago erregistratuta gune honetan.',
'pass_erreur_non_valide' => '<b>Errorea :</b> @email_oubli@ helbide hau ez da zuzena.',
'pass_erreur_probleme_technique' => '<b>Errorea :</b> arazo tekniko bat dela eta, mezua ezin izanda bidali.',
'pass_espace_prive_bla' => 'Gune honetako eremu pribatua zabalik dago, inskripzio baten bitartez. 
Behin erregistratuta, idazteko bidean dauden artikuluak kontsultatu, artikuluak proposatu eta foro guztietan parte hartzen ahalko duzu.',
'pass_forum_bla' => 'pertsona erregistratuei mugatutako foro batean parte hartzea eskatu duzu.',
'pass_indiquez_cidessous' => 'Lehen erregistratuta zinen helbide elektronikoa adierzai.
Zure sarbidea berreskuratzeko jarraitu behar duzun prozesua adierazten duen mezu bat jasoko duzu.',
'pass_mail_passcookie' => '(hau mezu automatikohau da)
Zure sarbidea berreskuratzeko  @nom_site_spip@ gunerarako (@adresse_site@)

Hurrengo helbidera joan: @sendcookie@

Orduan pasahitza berri bat jarri eta gunera berriz konektatzen ahalko zara. ',
'pass_mot_oublie' => 'Pasahitza ahaztua',
'pass_nouveau_enregistre' => 'Zure pasahitz berria erregistratua izan da.',
'pass_nouveau_pass' => 'Pasahitz berria',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Pasahitza ahaztu dut',
'pass_quitter_fenetre' => 'Leiho honetatik irten',
'pass_rappel_login' => 'Gogoan izan: zure identifikatzailea (logina) hau da : &laquo;@login@&raquo;.',
'pass_recevoir_mail' => 'Gunerako sarbidea nola berreskuratzen ahal duzun zehazten duen mezu bat jasoko duzu.',
'pass_retour_public' => 'Itzuli eremu publikora',
'pass_rien_a_faire_ici' => 'Hemen ez dago ezer egitekorik.',
'pass_vousinscrire' => 'Gune honetan izena eman',
'precedent' => 'aurrekoa',
'previsualisation' => 'Aurrebista',
'previsualiser' => 'Aurrebistaratu',

// R
'retour' => 'Itzulera',

// S
'spip_conforme_dtd' => 'SPIP-ek dokumentu hau bere DOCTYPE-ari konforme gisa konsideratzen du :',
'squelette' => 'eskeletoa',
'squelette_inclus_ligne' => 'eskeletoa barne, lerroa',
'squelette_ligne' => 'eskeletoa, lerroa',
'stats_visites_et_popularite' => '@visites@ bisitak; arrakasta : @popularite@',
'suivant' => 'hurrengoa',

// T
'taille_ko' => '@taille@ KB',
'taille_mo' => '@taille@ MB',
'taille_octets' => '@taille@ byte',
'texte_actualite_site_1' => 'Behin interfazera ohitua zarenean, klikatu &laquo;',
'texte_actualite_site_2' => 'interfaze osoa',
'texte_actualite_site_3' => '&raquo;-an,oraindik aukera gehiago dituena.',
'texte_creation_automatique_vignette' => 'Gune honek miniatura-sorkuntza automatikoa onartzen du hurrengo formatuetan : @gd_formats@. Inprimaki honekin instalatzen dituzun irudiek @taille_preview@ pixeletako ikonoak izango dituzte.',
'texte_documents_associes' => 'Hurrengo dokumentuak artikuluarekin elkartuak daude, baina ez dira zuzenean sartu. Eremu publikoaren formatuaren arabera, erantsitako dokumentuak bezala ager daitezke.',
'texte_erreur_mise_niveau_base' => 'Datu-basearen errorea eguneratzearen bidean.
 <b>@fichier@</b> irudia ez da pasatu (@id_article@ artikulua).
Erreferentzia hau idatzi, eguneratzen berriz saiatu eta irudiak artikuluetan agertzen direla egiaztatu.',
'texte_erreur_visiteur' => 'Saiatu zira eremu pribatura sartzea onartua ez den login batekin.',
'texte_inc_auth_1' => '<b>@auth_login@</b> login-arekin sartu zinen, baina login hau ez dago basean.
Saiatu berriro beste login batekin.',
'texte_inc_auth_2' => 'berriro konektatu',
'texte_inc_auth_3' => ',ebentualki zure nabigatzailea itxi eta berrabiarazi.',
'texte_inc_config' => 'Orrialde hauetan egindako aldaketek zure gunearen funtzionamenduan eragin nabaria dute.
SPIP sistemaren funtzionamendura ohituta ez zauden bitartean, parte ez hartzea gomendatzen dizugu.
Modu orokorrean, orrialde hauetako kudeaketa zure guneko web arduradun nagusiari uztea biziki gomendatzen da.',
'texte_inc_meta_1' => 'Sistemak errore bat aurkitu du <code>@fichier@</code> artxiboa idaztean. Webgunearen administratzailea zarenez,',
'texte_inc_meta_2' => 'idazteko baimenak egiaztatu barik',
'texte_inc_meta_3' => '<code>@repertoire@</code> direktorioarena',
'texte_statut_en_cours_redaction' => 'Idazteko bidean',
'texte_statut_poubelle' => 'Paperontzira',
'texte_statut_propose_evaluation' => 'Azterketarako proposatuta',
'texte_statut_publie' => 'Argitaratuta',
'texte_statut_refuse' => 'Ezeztatuta',
'titre_ajouter_mot_cle' => 'Gako-hitz bat erantsi',
'titre_breve_proposee' => 'Proposatutako laburra',
'titre_breve_publiee' => 'Argitaratutako laburra',
'titre_breve_refusee' => 'Ezeztatutako laburra',
'titre_cadre_raccourcis' => 'Lasterbideak',
'titre_changer_couleur_interface' => 'Interfaz-eko kolorea aldatu',
'titre_forum' => 'Barne-foroa',
'titre_image_admin_article' => 'Artikulu hau kudea dezakezu',
'titre_image_administrateur' => 'Administratzailea',
'titre_image_aide' => 'Osagai honi buruzko laguntza',
'titre_image_auteur_supprime' => 'Egile ezabatuta',
'titre_image_redacteur' => 'Baimenik gabeko idazlaria',
'titre_image_redacteur_02' => 'Idazlaria',
'titre_image_visiteur' => 'Bisitaria',
'titre_joindre_document' => 'Dokumentu bat erantsi',
'titre_liens_entrants' => 'Eguneko gehitutako loturak',
'titre_mots_cles' => 'Gako-hitzak',
'titre_probleme_technique' => 'ADI EGON: arazo tekniko bat dela eta (SQL zerbitzaria) ezin da tokiaren atal honetara sartu',
'titre_publier_document' => 'Atal honetan dokumentu bat argitaratu',
'titre_signatures_attente' => 'Baldazio baten behako sinadurak',
'titre_signatures_confirmees' => 'Baieztatutako sinadurak',
'titre_statistiques' => 'Gunearen estatistikak',
'titre_titre_document' => 'Dokumentuaren izenburua',
'todo' => 'etortzekoak',
'trad_reference' => '(erreferentziazko artikulua)',

// Z
'zbug_balise_b_aval' => ': B begiztako baliza aurrerago',
'zbug_balise_inexistante' => '@from@ errorea: @balise@ etiketa ez da existitzen',
'zbug_balise_sans_argument' => 'Argumento eskasa @balise@ etiketan',
'zbug_boucle' => 'begizta',
'zbug_boucle_recursive_undef' => 'zehaztu gabeko begizta errekurtsiboa',
'zbug_calcul' => 'kalkulua',
'zbug_champ_hors_boucle' => '@champ@ eremua begiztaren kanpoan',
'zbug_champ_hors_motif' => '@champ@ eremua @motif@ arrazoiko begizta baten kanpoan',
'zbug_code' => 'kodea',
'zbug_critere_inconnu' => '@critere@ irizpide ezezaguna',
'zbug_distant_interdit' => 'kanpoko debekatua',
'zbug_doublon_table_sans_cle_primaire' => 'Errepikak lehen mailako giltza atomiko gabeko mahai batean',
'zbug_doublon_table_sans_index' => 'Errepikak indizerik gabeko mahai batean',
'zbug_erreur_boucle_double' => '@id@ begizta: definizio bikoitza',
'zbug_erreur_boucle_fermant' => '@id@ begizta : hertsidura-baliza falta da',
'zbug_erreur_boucle_syntaxe' => 'Begizta okerraren sintaxia',
'zbug_erreur_compilation' => 'Konpilazio errorea',
'zbug_erreur_execution_page' => 'Orrialdearen exekuzio errorea',
'zbug_erreur_filtre' => 'Errorea: &laquo; @filtre@ &raquo; iragazkia ez dago mugaturik',
'zbug_erreur_meme_parent' => '{meme_parent} irizpidea (FORUMS) edo (RUBRIQUES) begiztetan bakarrik aplikatzen da',
'zbug_erreur_squelette' => 'Errorea(k) eskeletoan',
'zbug_hors_compilation' => 'Konpilaziotik at',
'zbug_info_erreur_squelette' => 'Akatsa gunean',
'zbug_inversion_ordre_inexistant' => 'Existitzen ez den ordena baten alderanzketa',
'zbug_pagination_sans_critere' => '#PAGINATION {pagination} irizpiderik gabeko edo begizta errekursibo batean enplegatutako baliza ',
'zbug_parametres_inclus_incorrects' => 'Baliogabeko inklusio-parametruak : @param@',
'zbug_profile' => 'kalkulu denbora&nbsp;: @time@',
'zbug_resultat' => 'emaitza',
'zbug_serveur_indefini' => 'SQL zerbitzari zehaztugabea',
'zbug_statistiques' => 'SQL eskaereb estatistikak, datez sailkatuak',
'zbug_table_inconnue' => '&laquo;@table@&raquo; SQL taula ezezaguna',
'zxml_connus_attributs' => 'Atributu ezagunak',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atributu ezezaguna',
'zxml_inconnu_balise' => 'etiketa ez ezaguna',
'zxml_inconnu_entite' => 'entitate ezezaguna',
'zxml_inconnu_id' => 'ID ezezaguna',
'zxml_mais_de' => 'baina',
'zxml_non_conforme' => 'ez da ereduari konforme',
'zxml_non_fils' => 'ez da hune seme bat ',
'zxml_nonvide_balise' => 'etiketa ez hutsa',
'zxml_obligatoire_attribut' => 'beharrezko atributua, baina eskas egiten duena hemen : ',
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte',
'zxml_survoler' => 'survoler pour voir les corrects',
'zxml_valeur_attribut' => 'atributuaren balorea',
'zxml_vide_balise' => 'etiketa hutsa',
'zxml_vu' => 'jadanik ikusia'
);

?>
